=====
py3-pilo
=====

forked 0.4.0 version from https://github.com/bninja/pilo and converted to python3, released to pypi as py3-pilo

.. image:: https://travis-ci.org/bninja/pilo.png
   :target: https://travis-ci.org/bninja/pilo

.. image:: https://coveralls.io/repos/bninja/pilo/badge.png
   :target: https://coveralls.io/r/bninja/pilo
